@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Installer for libarchive
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 sub versions_available
@@ -456,6 +456,11 @@ sub dlls
     }
   }
   
+  if($prefix eq '' && $self->{dll_dir}->[0] eq '')
+  {
+    shift @{ $self->{dll_dir} };
+  }
+  
   require File::Spec;
   map { File::Spec->catfile($prefix, @{ $self->{dll_dir} }, $_ ) } @{ $self->{dlls} };
 }
@@ -594,7 +599,7 @@ Alien::Libarchive::Installer - Installer for libarchive
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
